@@ -69,6 +69,13 @@ impl Kubectl {
         Ok(text)
     }
 
+    pub async fn create_global_crd(
+        &self,
+        crd: apiextensionsv1::CustomResourceDefinition,
+    ) -> kube::Result<apiextensionsv1::CustomResourceDefinition> {
+        self.create_global_crd_impl(crd).await
+    }
+
     pub async fn ensure_global_k_is_installed<K>(&self, object: K) -> kube::Result<K>
     where
         K: kube::ResourceExt + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
